#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 roman-numerals
version:              0.5.1.5
visibility:           public
id:                   roman-numerals-0.5.1.5-2EFSqmZ5KhRBgeUECKpJwd
key:                  roman-numerals-0.5.1.5-2EFSqmZ5KhRBgeUECKpJwd
license:              BSD-3-Clause
copyright:            2009–2014 Roel van Dijk
maintainer:           Roel van Dijk <vandijk.roel@gmail.com>
author:               Roel van Dijk <vandijk.roel@gmail.com>
stability:            stable
homepage:             https://github.com/roelvandijk/roman-numerals
synopsis:             Parsing and pretty printing of Roman numerals
description:
    This library provides functions for parsing and pretty printing
    Roman numerals. Because the notation of Roman numerals has varied
    through the centuries this package allows for some customisation
    using a configuration that is passed to the conversion functions.

category:             Numerical, Parsing
abi:                  287130b6d6d184fd446299d87953631b
exposed:              True
exposed-modules:      Text.Numeral.Roman
import-dirs:          /usr/lib/ghc-9.6.6/site-local/roman-numerals-0.5.1.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/roman-numerals-0.5.1.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/roman-numerals-0.5.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-roman-numerals
hs-libraries:         HSroman-numerals-0.5.1.5-2EFSqmZ5KhRBgeUECKpJwd
depends:
    base-4.18.2.1 base-unicode-symbols-0.2.4.2-LX7whyw4bmGCqzVQbQIjtq
    bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-roman-numerals/html/roman-numerals.haddock

haddock-html:         /usr/share/doc/haskell-roman-numerals/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

